@@ -304,7 +304,8 @@ class GaussianMixtureBase(metaclass=ABCMeta):
 
         for i in range(self.n_comps_found_):
             if self.centers_array_[i, 7] > 5 * weighted_phase_err or \
-                self.centers_array_[i, 8] > 5 * weighted_clust_err:
+                self.centers_array_[i, 8] > 5 * weighted_clust_err or \
+                self.ips_ <= 10:
                 self.noise_colors_.append(colors[self.unique_labels_[i]])
 
     @abstractmethod
@@ -485,7 +486,7 @@ class GaussianMixtureBase(metaclass=ABCMeta):
                     for n in self.unique_labels_:
                         cluster_ions = labels_list.count(n)
                         ips.append(cluster_ions)
-                    self.ips_ = np.array(ips)
+                    self.ips_ = np.array(ips).reshape(-1,)
 
                     # Recalculate centers
                     self.recalculate_centers_uncertainties(data_frame_object=data_frame_object)
